@@ -1,6 +1,6 @@
 /*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
  *
- *  Use of this source code is governed by a GPLv3+/MPLv2+ license that can
+ *  Use of this source code is governed by a BSD-style license that can
  *  be found in the License.html file in the root of the source tree.
  */
 
@@ -224,7 +224,7 @@ const std::string& Core::get_implementation_schema_file()
 }
 
 //---------------------------------------------------------------------------
-void Core::create_default_implementation_schema()
+int Core::create_default_implementation_schema(std::string& err)
 {
     std::string path = get_local_data_path();
     std::string file = path + "MatroskaSchema.xml";
@@ -233,12 +233,17 @@ void Core::create_default_implementation_schema()
     ofs.open(file.c_str(), std::ofstream::out | std::ofstream::binary);
 
     if (!ofs.is_open())
-        return;
+    {
+        err = "Unable to write implementation schema file.";
+        return -1;
+    }
 
     ofs << xsl_schema_matroska_schema;
     ofs.close();
 
     set_implementation_schema_file(file);
+
+    return 0;
 }
 
 //---------------------------------------------------------------------------
@@ -480,7 +485,7 @@ long Core::checker_analyze(int user, const std::string& filename, long src_id, s
 //--------------------------------------------------------------------------
 int Core::checker_list_mediainfo_outputs(std::string& output, std::string& err)
 {
-    output = Ztring(MI->Option(L"Info_OutputFormats_JSON")).To_UTF8();
+    output = Ztring(MI->Option(__T("Info_OutputFormats_JSON"))).To_UTF8();
 
     return 0;
 }
