@@ -1,6 +1,6 @@
 /*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
  *
- *  Use of this source code is governed by a GPLv3+/MPLv2+ license that can
+ *  Use of this source code is governed by a BSD-style license that can
  *  be found in the License.html file in the root of the source tree.
  */
 
@@ -733,9 +733,9 @@ const std::string& MediaConchLib::get_implementation_schema_file()
 }
 
 //---------------------------------------------------------------------------
-void MediaConchLib::create_default_implementation_schema()
+int MediaConchLib::create_default_implementation_schema(std::string& err)
 {
-    core->create_default_implementation_schema();
+    return core->create_default_implementation_schema(err);
 }
 
 //---------------------------------------------------------------------------
