@@ -1,6 +1,6 @@
 /*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
  *
- *  Use of this source code is governed by a GPLv3+/MPLv2+ license that can
+ *  Use of this source code is governed by a BSD-style license that can
  *  be found in the License.html file in the root of the source tree.
  */
 
@@ -369,7 +369,7 @@ public:
     // Implementation checker arguments
     void               set_implementation_schema_file(const std::string& file);
     const std::string& get_implementation_schema_file();
-    void               create_default_implementation_schema();
+    int                create_default_implementation_schema(std::string& err);
     void               set_implementation_verbosity(const std::string& verbosity);
     const std::string& get_implementation_verbosity();
 
