@@ -1,6 +1,6 @@
 /*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
  *
- *  Use of this source code is governed by a GPLv3+/MPLv2+ license that can
+ *  Use of this source code is governed by a BSD-style license that can
  *  be found in the License.html file in the root of the source tree.
  */
 
@@ -41,7 +41,7 @@ namespace MediaConch
     //**************************************************************************
     // Daemon
     //**************************************************************************
-    std::string Daemon::version = "17.12.0";
+    std::string Daemon::version = "18.03.2.0";
 
     //--------------------------------------------------------------------------
     Daemon::Daemon() : is_daemon(true), httpd(NULL), logger(NULL), watch_folder_user(NULL),
@@ -73,7 +73,13 @@ namespace MediaConch
 
         // If no Implementation Schema registered, use one by default
         if (!MCL->get_implementation_schema_file().length())
-            MCL->create_default_implementation_schema();
+        {
+            if (MCL->create_default_implementation_schema(err) != 0)
+            {
+                std::clog << err << std::endl;
+                return -1;
+            }
+        }
 
         // Load policy
         MCL->load_system_policy();
