@@ -253,9 +253,9 @@ var checkerAjax = (function() {
         webpage.on_save_policy_report(fileId, policy, display);
     };
 
-    var downloadReportUrl = function(fileId, reportType) {
+    var downloadReportUrl = function(fileId, reportType, output) {
         if (reportType === "mi")
-            webpage.on_save_mediainfo_report(fileId);
+            webpage.on_save_mediainfo_report(fileId, output ? output : "");
         else if (reportType === "mt")
             webpage.on_save_mediatrace_report(fileId);
     };
@@ -277,6 +277,13 @@ var checkerAjax = (function() {
         }
     };
 
+    var getMediaInfoOutputList = function(fileId) {
+        webpage.on_fill_output_list(function(res) {
+            data = JSON.parse(res);
+            mediaInfoCell.updateOutputList(data, fileId);
+        });
+    };
+
     var closeAll = function() {
         webpage.close_all();
     };
@@ -300,6 +307,7 @@ var checkerAjax = (function() {
         downloadPolicyReportUrl: downloadPolicyReportUrl,
         downloadReportUrl: downloadReportUrl,
         reportTreeUrl: reportTreeUrl,
+        getMediaInfoOutputList:getMediaInfoOutputList,
         addExisting: addExisting,
         closeAll: closeAll,
         closeElement: closeElement,
