@@ -43,6 +43,38 @@ var policyTreeAjax = (function() {
             mcoMessage.error(data.error);
     }
 
+    var policyCreateFromFile = function(form) {
+        createPolicyFromFile.addSpinner();
+        /**
+         * Create a policy from a file (the file is provided as POST data from a form)
+         *
+         * @return json
+         * {"policy":POLICY_JSTREE_JSON}
+         */
+         webpage.policy_from_file(function(res) {
+             data = JSON.parse(res);
+             $("#xslPolicyCreateFromFile_file").val("");
+             if (data.error) {
+                 mcoMessage.error(data.error);
+                 createPolicyFromFile.removeSpinner();
+             }
+         });
+    }
+
+    var policyCreateFromFileCallback = function(policyId) {
+        webpage.policy_get_jstree(policyId, function(res) {
+            data = JSON.parse(res);
+            if (!data.error) {
+                policyTree.policyCreateFromFile(data.policyTree);
+                createPolicyFromFile.removeSpinner();
+            }
+            else {
+                mcoMessage.error(data.error);
+                createPolicyFromFile.removeSpinner();
+            }
+        });
+    }
+
     var policyCreate = function(policyNode, parentId) {
         /**
          * Create a policy
@@ -361,6 +393,9 @@ var policyTreeAjax = (function() {
     return {
         getData: getData,
         policyImport: policyImport,
+        policyDropped: policyDropped,
+        policyCreateFromFile: policyCreateFromFile,
+        policyCreateFromFileCallback: policyCreateFromFileCallback,
         policyCreate: policyCreate,
         policyEdit: policyEdit,
         policyDelete: policyDelete,
@@ -374,6 +409,5 @@ var policyTreeAjax = (function() {
         ruleMove: ruleMove,
         getFieldsList: getFieldsList,
         getValuesList: getValuesList,
-        policyDropped: policyDropped,
     };
 })();
